import { getScheduleDetail, getUserScheduleInTime, uploadPermissions } from '../../api/request.js'
import { throttle } from './../../utils/utils.js'
import create from 'dd-store'
import exampleStore from '/stores/exampleStore'
create.Page({
  store: exampleStore,
  useAll: true,
  data: {
    // 传给组件list 的所有数据 comListData
    comListData: {
      repeatList: [
        { id: 0, text: '不重复', icon: 'iconicon_cycle', repeatable: 0, recurrenceModel: { model: 'no_repeat' } },
        { id: 1, text: '每天', icon: '', repeatable: 1, recurrenceModel: { model: 'daily', interval: 1, initialTime: `2020-03-23`, terminateTime: `2022-03-23`, weekDayList: null } },
        { id: 2, text: '每周', icon: '', repeatable: 1, recurrenceModel: { model: 'weekly', interval: 1, initialTime: `2020-03-23`, terminateTime: `2022-03-23`, weekDayList: ['MO'] } },
        { id: 3, text: '每周的工作日', icon: '', repeatable: 1, recurrenceModel: { model: 'weekly', interval: 1, initialTime: `2020-03-23`, terminateTime: `2022-03-23`, weekDayList: ['MO', 'TU', 'WE', 'TH', 'FR'] } },
        { id: 4, text: '每月', icon: '', repeatable: 1, recurrenceModel: { model: 'absoluteMonthly', daysOfMonth: ['23'], interval: 1, initialTime: `2020-03-23`, terminateTime: `2022-03-23`, weekDayList: null } }
      ],
      meetingWayList: [
        { id: 0, text: 'Webex meeting', imageUrl: '../../assests/Webex.png', meetingWayModel: { model: 'webex' } },
        { id: 1, text: 'Zoom Meeting', imageUrl: '../../assests/Zoom.png', meetingWayModel: { model: 'zoom' } },
        { id: 2, text: '钉钉', imageUrl: '../../assests/dingding.png', meetingWayModel: { model: 'dingtalk' } }
      ],
      comSelectListId: 0,
      meetingWayModelId: null,
      iconType: 'icon'
    },
    // 传给组件 hList 水平排列  所有数据 comHListData
    comHListData: {
      contactData: [
        { id: 0, text: '钉钉联系人', imageUrl: '../../assests/dingContact.png' },
        { id: 1, text: '手动添加邮箱', imageUrl: '../../assests/emailContact.png' }
      ]
    },
    // 传递给组件toast的所有数据
    conToastData: {
      showToast: false
    },
    // 传递给组件selectPopup 的数据
    conSelectPopupData: {
      showSelectPopup: true,
      editSaveList: [{text: '仅接受此会议', id: 'only'},{text: '接受所有会议', id: 'all'}]
    },
    title: ``,
    repeatable: 0,
    recurrenceModel: { model: 'no_repeat' },
    isShowRemark: false,
    repeatWeek: ['SU', 'MO', 'TU', 'WE', 'TH', 'FR', 'SA'],
    popupTitle: '会议重复',
    popupShow: false,
    comType: '',
    remark: '',
    comTimeType: '',
    meetingWayModel: null,
    weekList: ['周日', '周一', '周二', '周三', '周四', '周五', '周六'],
    week: '',
    conflictPeople: [],
    isAcrossDay: false,
    scheduleItem: '',
    originalData: new Map()
  },

  showPop() {
    this.setData({
      show: true
    })
  },
  closePop() {
    this.setData({
      show: false
    })
  },
  Complete(data) {
    console.log(data)
    this.closePop();
  },
  onLoad(event) {
    dd.setNavigationBar({
      title: `会议详情`
    })
    this.setData({
      scheduleItem: JSON.parse(event.scheduleItem)
    })
    this.getDetail()
  },
  // 获取详情
  getDetail() {
    let data = {
      id: this.data.scheduleItem.id,
      scheduleTemplateId: this.data.scheduleItem.scheduleTemplateId,
      planDate: this.data.scheduleItem.planDate
    }
    getScheduleDetail(data).then(res => {
      if (res.data.code === 0) {
        let participatorList = []
        let repeatListMap = new Map()
        for (let value of res.data.data.userList) {
          participatorList.push(value.participator)
        }
        for (let item of this.data.comListData.repeatList) {
          if (item.recurrenceModel.recurrenceModel !== 'weekly') {
            repeatListMap.set(item.recurrenceModel.model, item.id)
          }
        }
        // console.log(repeatListMap, 111)
        this.setData({
          'scheduleItem.id': res.data.data.id,
          'comListData.comSelectListId': res.data.data.recurrenceModel.model === 'weekly' ? (res.data.data.recurrenceModel.weekDayList.length > 1 ? 3 : 2) : repeatListMap.get(res.data.data.recurrenceModel.model),
          'comListData.meetingWayModelId': res.data.data.meetingWayModel === 'dingtalk' ? 2 : (res.data.data.meetingWayModel === 'zoom' ? 1 : 0),
          repeatable: res.data.repeatable,
          recurrenceModel: res.data.repeatable ? { model: res.data.data.recurrenceModel.model, daysOfMonth: res.data.data.recurrenceModel.daysOfMonth, interval: 1, initialTime: res.data.data.initialTime, terminateTime: res.data.data.terminateTime, weekDayList: res.data.data.weekDayList } : { model: 'no_repeat' },
          originalData: res.data.data,
          title: res.data.data.title,
          remark: res.data.data.remark,
          isShowRemark: res.data.data.remark ? true : false,
          week: this.data.weekList[new Date(res.data.data.startTime.replace(/'-'/g, "\/")).getDay()]
        })
        this.store.data.locationName = res.data.data.location.locationName
        this.store.data.roomId = res.data.data.meetingRoomId < 0 ? '' : res.data.data.meetingRoomId
        this.store.data.startTime = res.data.data.startTime.replace(/'-'/g, "\/")
        this.store.data.endTime = res.data.data.endTime.replace(/'-'/g, "\/")
        this.store.data.participatorList = participatorList
        this.update()
        this.conflictPeople()
        console.log(res.data.data)
      }
    })
  },
  // 添加描述
  addRemark() {
    let isShowRemark = !this.data.isShowRemark
    if (!isShowRemark) {
      this.setData({
        remark: ''
      })
    }
    this.setData({
      isShowRemark: isShowRemark
    })
    this.update()

  },
  // 输入框输入事件
  onInput(event) {
    switch (event.target.dataset.type) {
      case 'title':
        this.setData({
          title: event.detail.value
        })
        break
      case 'remark':
        this.setData({
          remark: event.detail.value
        })
        break
    }
  },
  // 初始化
  reset() {
    this.store.data.roomId = ''
    this.store.data.participatorList = []
    this.store.data.participatorUserId = []
    this.store.data.locationName = ''
    this.store.data.startTime = this.getTimes()
    this.store.data.endTime = this.getTimes(new Date(this.getTimes()).setMinutes(new Date(this.store.data.startTime).getMinutes() + 120))
    this.update()
    this.resetRepeatList()
    this.acrossDay(this.store.data.startTime, this.store.data.endTime)
  },
  // 跳转下一页
  nextPage(event) {
    switch (event.target.dataset.nextPage) {
      case 'location':
        dd.navigateTo({ url: './../place/place' })
        break
      case 'participantsDetail':
        dd.navigateTo({ url: `./../participantsDetail/participantsDetail?scheduleItem=${JSON.stringify(this.data.scheduleItem)}` })
        break
    }
  },
  // 所有的关闭操作
  close(event) {
    switch (event.target.dataset.close) {
      case 'location':
        this.store.data.locationName = ''
        this.store.data.roomId = ''
        this.update()
        break
      case 'meetingWayModel':
        this.setData({
          'comListData.meetingWayModelId': null,
          meetingWayModel: null
        })
    }
  },
  // 关闭popup 点击mark
  closePopup() {
    this.setData({
      popupShow: false
    })
  },
  // 选择循环机制 选择会议方式  选择时间  出现popup弹窗
  showPopup(event) {
    let iconType = ''
    switch (event.currentTarget.dataset.type) {
      case 'meetingWayModel':
        iconType = 'image'
        break
      case 'repeat':
        iconType = 'icon'
        break
      case 'participator':
        break
      case 'time':
        break
    }
    this.setData({
      popupShow: true,
      comType: event.currentTarget.dataset.type,
      'comListData.iconType': iconType
    })
  },
  resetRepeatList() {
    let index = 0
    let repeatList = []
    for (let value of this.data.comListData.repeatList) {
      if (index) {
        value.recurrenceModel.initialTime = this.store.data.startTime.replace(/\//g, "-").substring(0, 10)
        value.recurrenceModel.terminateTime = this.getTwoYearToday(this.store.data.startTime)
        if (index === 2) {
          value.recurrenceModel.weekDayList = [this.data.repeatWeek[new Date().getDay()]]
        } else if (index === 4) {
          value.recurrenceModel.daysOfMonth = this.store.data.startTime.replace(/\//g, "-").substring(8, 10)
        }
      }
      repeatList.push(value)
      index++
    }
    this.setData({
      'comListData.repeatList': repeatList,
      week: this.data.weekList[new Date().getDay()]
    })

  },
  // 选择完comList后的回调
  selectComList(event) {
    switch (this.data.comType) {
      case 'meetingWayModel':
        this.setData({
          'comListData.meetingWayModelId': event.currentTarget.dataset.item.id,
          popupShow: false,
          meetingWayModel: this.data.comListData.meetingWayList[event.currentTarget.dataset.item.id].meetingWayModel
        })
        break;
      case 'repeat':
        this.resetRepeatList()
        this.setData({
          popupShow: false,
          'comListData.comSelectListId': event.currentTarget.dataset.item.id,
          repeatable: event.currentTarget.dataset.item.repeatable,
          recurrenceModel: event.currentTarget.dataset.item.recurrenceModel
        })
        break;
    }
  },
  // 选择完水平 HList 的回调
  selectComHList(event) {
    console.log(event)
    switch (event.currentTarget.dataset.item.id) {
      case 0:
        this.addParticipator()
        this.setData({
          popupShow: false
        })
        break;
      case 1:
        this.setData({
          popupShow: false
        })
        dd.navigateTo({ url: './../outLookContact/outLookContact' })
        break;
    }
  },
  // 获取两年后的今天
  getTwoYearToday(startTime) {
    let date = new Date(startTime)
    date.setYear(date.getFullYear() + 2)
    let year = date.getFullYear();
    let month = date.getMonth() + 1 < 10 ? '0' + (date.getMonth() + 1) : date.getMonth() + 1;
    let day = date.getDate() < 10 ? '0' + date.getDate() : date.getDate()
    return year + '-' + month + '-' + day
  },
  // 添加参会人
  addParticipator() {
    const _that = this
    let require = []
    let select = []
    select = this.store.data.participatorUserId
    require = [getApp().globalData.userid]
    select = _that.selectedelRequired(require, select).pickedUsers
    dd.complexChoose({
      title: "选择参会人",            //标题
      multiple: true,            //是否多选
      pickedUsers: select, //已选用户
      requiredUsers: require,            //必选用户（不可取消选中状态）
      responseUserOnly: true,        //返回人，或者返回人和部门
      success: function (res) {
        _that.store.data.participatorList = []
        _that.store.data.participatorUserId = []
        _that.store.data.participatorList.push({ userId: getApp().globalData.userid, username: getApp().globalData.name, headUrl: getApp().globalData.avatar, platform: 'dingtalk' })
        _that.store.data.participatorUserId.push(getApp().globalData.userid)
        res.users.forEach((item, index) => {
          _that.store.data.participatorList.push({ userId: item.userId, username: item.name, headUrl: item.avatar, platform: 'dingtalk' })
          _that.store.data.participatorUserId.push(item.userId)
        })
        _that.store.data.participatorList = _that.setArrary(_that.store.data.participatorList)
        _that.store.data.participatorUserId = [...new Set(_that.store.data.participatorUserId)]
        _that.update()

      },
      fail: function (err) {
      }
    })
  },
  // 已选用户去中去掉必选用户
  selectedelRequired(req, pic) {
    for (let i = 0; i < req.length; i++) {
      for (let m = 0; m < pic.length; m++) {
        if (req[i] == pic[m]) {
          pic.splice(m, 1)
          m--;
        }
      }
    }
    return {
      requiredUsers: req,
      pickedUsers: pic
    }
  },
  // 数组 去重
  setArrary(arr) {
    let containt = {}
    for (let x of arr) {
      containt['id' + x.userId] = x
    }
    return Object.values(containt)
  },
  // 点击完成
  onComplete(event) {
    this.store.data.startTime = `${event.startTime}:00`
    this.store.data.endTime = `${event.endTime}:00`
    this.update()
    this.acrossDay(this.store.data.startTime, this.store.data.endTime)
    this.setData({
      popupShow: false
    })
  },
  addSchedule() {
    let data = {
      title: this.data.title || `${getApp().globalData.name}创建的会议`,
      location: {
        longitude: '10',
        latitude: '10',
        locationName: this.store.data.locationName
      },
      startTime: this.store.data.startTime.replace(/\//g, "-"),
      endTime: this.store.data.endTime.replace(/\//g, "-"),
      meetingRoomId: this.store.data.roomId,
      scheduleType: this.store.data.roomId ? 'meeting' : 'common',
      participatorList: !!this.store.data.participatorList.length ? this.store.data.participatorList : [{ userId: getApp().globalData.userid, username: getApp().globalData.name, headUrl: getApp().globalData.avatar }],
      repeatable: this.data.repeatable,
      remark: this.data.remark,
      recurrenceModel: this.data.recurrenceModel,
      meetingRoomId: this.store.data.roomId,
      meetingWayModel: this.data.meetingWayModel
    }
    addSchedule(data).then(res => {
      console.log(res)
      if (res.data.code === 0) {
        dd.navigateBack({
          delta: 1
        })
      }
    })
  },
  // 获取时间参数
  getTimes(time = new Date()) {
    let date = new Date(time)
    let year = date.getFullYear()
    let month = date.getMonth() + 1 < 10 ? '0' + (date.getMonth() + 1) : date.getMonth() + 1
    let day = date.getDate() < 10 ? '0' + date.getDate() : date.getDate()
    let hour = date.getHours() < 10 ? '0' + date.getHours() : date.getHours()
    let miunutes = date.getMinutes() < 10 ? '0' + date.getMinutes() : date.getMinutes()
    return `${year}/${month}/${day} ${hour}:${miunutes}:00`
  },
  // 是否跨天
  acrossDay(time1, time2) {
    let isAcrossDay = ''
    if (JSON.stringify(this.getTimes(time1).substring(0, 10)) === JSON.stringify(this.getTimes(time2).substring(0, 10))) {
      isAcrossDay = false
    } else {
      isAcrossDay = true
    }
    this.setData({
      isAcrossDay: isAcrossDay
    })
  },
  // 人员冲突
  conflictPeople() {
    let userIds = []
    for (let value of this.store.data.participatorList) {
      userIds.push(value.userId)
    }
    let data = {
      startTime: this.store.data.startTime.replace(/\//g, "-"),
      endTime: this.store.data.endTime.replace(/\//g, "-"),
      userIds: userIds
    }
    getUserScheduleInTime(data).then(res => {
      let conflictPeople = []
      for (let value in res.data.data) {
        if (res.data.data[value].length > 1) {
          conflictPeople.push(value)
        }
      }
      this.setData({
        conflictPeople: conflictPeople
      })
    })
  },
  // 文件上传
  uploadFile() {
    let data = {
      ddUserId: getApp().globalData.userid,
      type: 'add',
      projectName: 'MING_MEETING'
    }
    uploadPermissions(data).then(res => {
      if (res.data.code === 0) {
        const _that = this
        dd.uploadAttachmentToDingTalk({
          image: { multiple: true, compress: true, max: 9, spaceId: res.data.data },
          space: { spaceId: res.data.data, compress: true, isCopy: 1, max: 9 },
          types: ["photo", "camera", "space"],
          success: (res) => {
            dd.navigateTo({ url: `./../uploadFile/uploadFile?scheduleItem=${JSON.stringify(_that.data.scheduleItem)}&upLoadInfo=${encodeURIComponent(JSON.stringify(res))}` })
          },
          fail: (err) => {
          }
        })
      }
    })

  },
  // toast 消失之后的回调
  onToastHidden () {


  },
  // onSelectPopup 选择完的回调
  onSelectPopup(event) {
    console.log(event.currentTarget.dataset.item)
     this.setData({
      'conSelectPopupData.showSelectPopup': false
    })
  },
  // onSelectPopupCancel 点击取消 
  onSelectPopupCancel() {
    this.setData({
      'conSelectPopupData.showSelectPopup': false
    })
  },
  // 判断数据发生改变 发生改变
  isChange(value) {
    switch (value) {
      case 'title':
      // if()
      break
    }

  }

  
});
